Chess opening names
===================

An aggregated data set of chess opening names.

field | description
--- | ---
eco | [ECO](https://en.wikipedia.org/wiki/Encyclopaedia_of_Chess_Openings) classification
name | Opening name (English language)
fen | [EPD](https://www.chessprogramming.org/Extended_Position_Description) of the root position (en passant field only if legal)
moves | Most common moves to reach the root position based on master games, in UCI notation

Contributing
------------

Improvements, additions and fixes are welcome.

Copyright
---------

As a collection of facts, this data set is in the public domain.
Considerable effort was spent curating and cleaning the data. Insofar as that
qualifies for copyright, the work is released under the
CC0 Public Domain Dedication.

[![CC0](https://i.creativecommons.org/p/zero/1.0/88x31.png)](https://creativecommons.org/publicdomain/zero/1.0/)
